@echo off
SETLOCAL EnableExtensions EnableDelayedExpansion
REM ----------------------------------------------------------------------------
REM Define environment variables
REM
set DESIGN_NAME=cursor
set HDS_PROJECT_DIR=%CD%

REM set and verify tool installation paths
set HDS_HOME=C:\eda\MentorGraphics\HDS
if not exist !HDS_HOME!\ (
	set HDS_HOME=C:\eda\HDS
	if not exist !HDS_HOME!\ (
		echo ERROR: No valid installtion of HDS found: please verify your HDS_HOME settings.
		pause
		exit
	)
)
echo Found HDL-Designer at !HDS_HOME!
set MODELSIM_HOME=C:\eda\modeltech_6.6g\win64
if not exist !MODELSIM_HOME!\ (
	set MODELSIM_HOME=C:\eda\MentorGraphics\Modelsim\win64
	if not exist !MODELSIM_HOME!\ (
		echo ERROR: No valid installtion of ModelSim found: please verify your MODELSIM_HOME settings.
		pause
		exit
	)
)
echo Found ModelSim     at !MODELSIM_HOME!
set ISE_HOME=C:\eda\Xilinx\ISE_DS\ISE\bin\nt
if not exist !ISE_HOME!\ (
	set ISE_HOME=C:\eda\Xilinx\14.7\ISE_DS\ISE\bin\nt64
	if not exist !ISE_HOME!\ (
		set ISE_HOME=C:\eda\Xilinx\12.1\ISE_DS\ISE\bin\nt64
		if not exist !ISE_HOME!\ (
			echo ERROR: No valid installtion of ISE found: please verify your ISE_HOME settings.
			pause
			exit
		)
	)
)
echo Found ISE          at !ISE_HOME!

REM set existing library installation paths
set HEI_LIBS_DIR=%HDS_PROJECT_DIR%\..\libs
if not exist !HEI_LIBS_DIR!\ (
	set HEI_LIBS_DIR=R:\SYND\Ele_2131\ELN\Labs\Libraries
	if not exist !HEI_LIBS_DIR!\ (
		echo ERROR: No valid libraries found: please verify your HEI_LIBS_DIR settings.
		pause
		exit
	)
)
echo Found Libs         at !HEI_LIBS_DIR!

REM ----------------------------------------------------------------------------
REM Prepare scratch directory
REM
ver | findstr /i "5\.1\." > nul 
IF %ERRORLEVEL% EQU 0 (
    REM Windows XP and older
    set SCRATCH_DIR=%USERPROFILE:C:\Documents and Settings=C:\temp\EDA%
) else (
    REM Windows Vista and newer
    set SCRATCH_DIR=%USERPROFILE:C:\Users=C:\temp\EDA%
)
set DESIGN_SCRATCH_DIR=%SCRATCH_DIR%\%DESIGN_NAME%

set HDS_PREFS_DIR=%HDS_PROJECT_DIR%\Prefs
set HDS_LIBS=%HDS_PREFS_DIR%\hds.hdp
set HDS_USER_HOME=%HDS_PREFS_DIR%\hds_user
set HDS_TEAM_HOME=%HDS_PREFS_DIR%\hds_team

set HDS_LIB_BOARD=%HDS_PROJECT_DIR%\board
set HDS_CONCAT_DIR=%HDS_LIB_BOARD%\concat

set SIMULATION_DIR=%HDS_PROJECT_DIR:\=/%/Simulation

set ISE_WORK_DIR=Board\ise
set ISE_PROJECT_WORK_DIR=%HDS_PROJECT_DIR%\%ISE_WORK_DIR%
set ISE_SCRATCH_WORK_DIR=%DESIGN_SCRATCH_DIR%\%ISE_WORK_DIR%

REM ----------------------------------------------------------------------------
REM Copy files to scratch directory
REM
echo.
echo Copying place and route files to scratch directory: %DESIGN_SCRATCH_DIR%
rmdir /S /Q "%DESIGN_SCRATCH_DIR%"
mkdir "%DESIGN_SCRATCH_DIR%"
xcopy /S /I /Y /Q /K "%ISE_PROJECT_WORK_DIR%" "%ISE_SCRATCH_WORK_DIR%"

REM ----------------------------------------------------------------------------
REM Delete intermediate files
REM
echo.
echo Deleting automatically generated files in: %HDS_PROJECT_DIR%
del /s %HDS_PROJECT_DIR%\*.bak %HDS_PROJECT_DIR%\*.lck %HDS_PROJECT_DIR%\.cache.dat
del /s %HDS_PROJECT_DIR%\*_entity.vhd %HDS_PROJECT_DIR%\*_struct.vhd %HDS_PROJECT_DIR%\*_fsm.vhd
del /s %HDS_PROJECT_DIR%\*.vhg

REM ----------------------------------------------------------------------------
REM Launch Application
REM
echo.
echo Launching programs
echo Waiting until programs finished... WARNING: DO NOT CLOSE THIS WINDOW!
%windir%\system32\cmd.exe /c start /wait !HDS_HOME!\bin\hdldesigner.exe
echo Programs finished

REM ----------------------------------------------------------------------------
REM Copy files back from the scratch directory
REM
echo.
echo Copying and overwrite place and route files to user directory
xcopy /Y /Q /K %ISE_SCRATCH_WORK_DIR%\%DESIGN_NAME%.xise %ISE_PROJECT_WORK_DIR%\
xcopy /Y /Q /K %ISE_SCRATCH_WORK_DIR%\*.bit %ISE_PROJECT_WORK_DIR%\
xcopy /Y /Q /K %ISE_SCRATCH_WORK_DIR%\*.mcs %ISE_PROJECT_WORK_DIR%\
echo Finished... YOU CAN CLOSE THIS WINDOW NOW!
REM pause
ENDLOCAL
